@@ -1,5 +1,5 @@
 #include <iostream.h>
-#include <qp.h>
+#include <qpthr/qp.h>
 
 class HelloWorld: public QpThread {
     public:
